@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/chgrp.c,v 1.12 2004/03/21 14:13:11 werner Exp $
  *
  * Change Group
  *
@@ -42,7 +40,7 @@ int ChangeFileGroup(FileEntry *fe_ptr)
 
 int GetNewGroup(int st_gid)
 {
-  char group[GROUP_NAME_MAX+1];
+  char group[GROUP_NAME_MAX * 2 +1];
   char *group_name_ptr;
   int  id;
   int  group_id;
