@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/copy.c,v 1.21 2004/11/13 21:08:05 werner Exp $
  *
  * Kopieren von Dateien / Verzeichnissen
  *
@@ -48,8 +46,8 @@ int CopyFile(Statistic *statistic_ptr,
   *to_path = '\0';
   if( strcmp( to_dir_path, FILE_SEPARATOR_STRING ) )
   {
-    /* nicht ROOT */
-    /*------------*/
+    /* not ROOT */
+    /*----------*/
 
     (void) strcat( to_path, to_dir_path );
   }
@@ -57,31 +55,27 @@ int CopyFile(Statistic *statistic_ptr,
   {
     (void) GetPath( fe_ptr->dir_entry, &to_path[strlen(to_path)] );
 
-    /* Sicherstellen, dass das Zielverzeichnis existiert */
-    /*---------------------------------------------------*/
+    /* Create destination folder (if neccessary) */
+    /*-------------------------------------------*/
     strcat(to_path, FILE_SEPARATOR_STRING );
-    if ((tmpdir = opendir(to_path)) == NULL)
-    {
-       if(*to_path != FILE_SEPARATOR_CHAR) {
+
+    if(*to_path != FILE_SEPARATOR_CHAR) {
          strcpy(abs_path, from_dir);
 	 strcat(abs_path, FILE_SEPARATOR_STRING);
 	 strcat(abs_path, to_path);
 	 strcpy(to_path, abs_path);
-       }
-
-       if( MakePath( statistic_ptr->tree, to_path, &dest_dir_entry ) )
-       {
-       	   (void) sprintf( message, 
-		           "Can't create path*\"%s\"*%s", 
-                           to_path, 
-                           strerror(errno) 
-                           );
-           MESSAGE( message );
-           return( result );
-       }
     }
-    else
-       closedir(tmpdir);
+
+    if( MakePath( statistic_ptr->tree, to_path, &dest_dir_entry ) )
+    {
+     	 (void) sprintf( message, 
+                         "Can't create path*\"%s\"*%s", 
+                         to_path, 
+                         strerror(errno) 
+                         );
+         MESSAGE( message );
+         return( result );
+    }
   }
   (void) strcat( to_path, FILE_SEPARATOR_STRING );
   if ((tmpdir = opendir(to_path)) == NULL)
@@ -150,7 +144,7 @@ int CopyFile(Statistic *statistic_ptr,
     
         if( term != 'Y' ) 
         {
-          result = 0;
+	  result = (term == 'N' ) ? 0 : -1;  /* Abort on escape */
           ESCAPE;
         }
       }
@@ -174,7 +168,7 @@ int CopyFile(Statistic *statistic_ptr,
       
         if( term != 'Y' ) 
         {
-          result = 0;
+	  result = (term == 'N' ) ? 0 : -1;  /* Abort on escape */
           ESCAPE;
         }
       }
@@ -404,8 +398,8 @@ static int CopyArchiveFile(char *to_path, char *from_path)
 {
   char *command_line;
   char buffer[PATH_LENGTH + 3];
-  char from_p_aux[PATH_LENGTH + 3];
-  char to_p_aux[PATH_LENGTH + 3];
+  char from_p_aux[PATH_LENGTH + 1];
+  char to_p_aux[PATH_LENGTH + 1];
   char *archive;
   int result = -1;
 
