@@ -23,8 +23,7 @@ static void MoveHome(DirEntry **dir_entry);
 static void HandlePlus(DirEntry *dir_entry, DirEntry *de_ptr, char *new_login_path, DirEntry *start_dir_entry, BOOL *need_dsp_help);
 static void HandleTagDir(DirEntry *dir_entry, BOOL value);
 static void HandleTagAllDirs(DirEntry *dir_entry, BOOL value );
-static void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
-static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
+static void HandleShowAll(BOOL tagged_only, DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
 static void HandleSwitchWindow(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
 
 static int dir_mode;
@@ -705,48 +704,11 @@ static void HandleTagAllDirs(DirEntry *dir_entry, BOOL value )
     return;
 }
 
-static void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
-{
-    if( statistic.disk_tagged_files )
-    {
-	if(dir_entry->login_flag) 
-	{
-	    dir_entry->login_flag = FALSE;
-	} else {
-	    dir_entry->big_window  = TRUE;
-            dir_entry->global_flag = TRUE;
-	    dir_entry->tagged_flag = TRUE;
-	    dir_entry->start_file  = 0;
-	    dir_entry->cursor_pos  = 0;
-	}
-	if( HandleFileWindow(dir_entry) != LOGIN_ESC )
-	{
-	    DisplayDiskStatistic();
-	    dir_entry->start_file = 0;
-	    dir_entry->cursor_pos = -1;
-            DisplayFileWindow( dir_entry );
-            RefreshWindow( small_file_window );
-            RefreshWindow( big_file_window );
-	    BuildDirEntryList( start_dir_entry );
-            DisplayTree( dir_window, statistic.disp_begin_pos, 
-			statistic.disp_begin_pos + statistic.cursor_pos);
-	}else{
-	    BuildDirEntryList( statistic.tree );
-            DisplayTree( dir_window, statistic.disp_begin_pos, 
-			statistic.disp_begin_pos + statistic.cursor_pos);
-	    *ch = 'L';
-	}
-    }else{
-	dir_entry->login_flag = FALSE;
-	beep();
-    }
-    *need_dsp_help = TRUE;
-    return;
-}
 
-static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
+
+static void HandleShowAll(BOOL tagged_only, DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
 {
-    if( statistic.disk_matching_files )
+    if( (tagged_only) ? statistic.disk_tagged_files : statistic.disk_matching_files )
     {
 	if(dir_entry->login_flag) 
 	{
@@ -754,7 +716,7 @@ static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *
 	} else {
 	    dir_entry->big_window  = TRUE;
 	    dir_entry->global_flag = TRUE;
-	    dir_entry->tagged_flag = FALSE;
+	    dir_entry->tagged_flag = tagged_only;
 	    dir_entry->start_file  = 0;
 	    dir_entry->cursor_pos  = 0;
 	}
@@ -768,7 +730,7 @@ static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *
             RefreshWindow( big_file_window );
 	    BuildDirEntryList( start_dir_entry );
             DisplayTree( dir_window, statistic.disp_begin_pos, 
-			statistic.disp_begin_pos + statistic.cursor_pos);
+			 statistic.disp_begin_pos + statistic.cursor_pos);
 	} else {
 	    BuildDirEntryList( statistic.tree );
             DisplayTree( dir_window, statistic.disp_begin_pos, 
@@ -1029,11 +991,11 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     need_dsp_help = TRUE;
 		     break;
       case 'S' & 0x1F : 
-		     HandleShowAllTagged(dir_entry, start_dir_entry, &need_dsp_help, &ch);
+		     HandleShowAll(TRUE, dir_entry, start_dir_entry, &need_dsp_help, &ch);
 		     break;
 
       case 'S':
-      case 's':      HandleShowAll(dir_entry, start_dir_entry, &need_dsp_help, &ch);
+      case 's':      HandleShowAll(FALSE, dir_entry, start_dir_entry, &need_dsp_help, &ch);
 		     break;
       case LF :
       case CR :      HandleSwitchWindow(dir_entry, start_dir_entry, &need_dsp_help, &ch);
