@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/execute.c,v 1.13 2004/11/13 20:38:40 werner Exp $
  *
  * Ausfuehren von System-Kommandos
  *
@@ -55,7 +53,11 @@ int Execute(DirEntry *dir_entry, FileEntry *file_entry)
         refresh();
         result = QuerySystemCall( command_line );
       }
-      (void) chdir( cwd );
+      if( chdir( cwd ) )
+      {
+        (void) sprintf( message, "Can't change directory to*\"%s\"", cwd );
+        MESSAGE( message );
+      }
     }
     else
     {
@@ -153,7 +155,7 @@ int ExecuteCommand(FileEntry *fe_ptr, WalkingPackage *walking_package)
   }
   *cptr = '\0';
 
-  result = SilentSystemCall( command_line );
+  result = SilentSystemCallEx( command_line, FALSE );
 
   /* Ignore Result */
   /*---------------*/
