@@ -65,6 +65,7 @@ static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */),
 static void RereadWindowSize(DirEntry *dir_entry);
 static void ListJump( DirEntry * dir_entry, char *str );
 static char GetTypeOfFile(struct stat fst);
+static int  GetVisualFileEntryLength(int mode, int max_visual_filename_len, int max_visual_linkname_len);
 
 
 
@@ -73,43 +74,52 @@ void SetFileMode(int new_file_mode)
 
   GetMaxYX( file_window, &window_height, &window_width );
   file_mode = new_file_mode;
-  switch( file_mode )
-  {
-    case MODE_1: if( max_visual_linkname_len)
-		   max_column = window_width / 
-				(max_visual_filename_len + max_visual_linkname_len + 45); 
-		 else
-		   max_column = window_width / (max_visual_filename_len + 41); 
-		 break;
-    case MODE_2: if( max_visual_linkname_len)
-		   max_column = window_width / 
-                   (max_visual_filename_len + max_visual_linkname_len + 41);
-		 else
-                   max_column = window_width / (max_visual_filename_len + 37);
-		 break;
-    case MODE_3: max_column = window_width / (max_visual_filename_len + 3);  
-    		 break;
-    case MODE_4: if( max_visual_linkname_len)
-		   max_column = window_width / 
-				(max_visual_filename_len + max_visual_linkname_len + 44); 
-		 else
-		   max_column = window_width / (max_visual_filename_len + 40); 
-		 break;
-    case MODE_5: max_visual_userview_len = GetVisualUserFileEntryLength(max_visual_filename_len, 
-					                                max_visual_linkname_len, 
-					                                USERVIEW);
-                 if(max_visual_userview_len)
-		   max_column = window_width / (max_visual_userview_len + 1);
-		 else
-		   max_column = 0;
-		 break;
-  }
+
+  max_column = window_width / 
+	       (GetVisualFileEntryLength( file_mode, max_visual_filename_len, max_visual_linkname_len) + 1);
 
   if( max_column == 0 ) 
     max_column = 1;
 }
 
 
+static int GetVisualFileEntryLength(int mode, int max_visual_filename_len, int max_visual_linkname_len)
+{
+  int len = 0;
+
+  switch (file_mode)
+  {
+    case MODE_1: len =  (max_visual_linkname_len) ? max_visual_linkname_len + 4 : 0; /* linkname + " -> " */
+		 len += max_visual_filename_len + 38; /* filename + format */
+#ifdef HAS_LONGLONG
+                 len += 4;  /* %11lld instead of %7d */
+#endif
+                 break;
+
+    case MODE_2: len =  (max_visual_linkname_len) ? max_visual_linkname_len + 4 : 0; /* linkname + " -> " */
+		 len += max_visual_filename_len + 40; /* filename + format */
+#ifdef HAS_LONGLONG
+                 len += 4;  /* %11lld instead of %7d */
+#endif
+                 break;
+
+    case MODE_3: len = max_visual_filename_len + 2; /* filename + format */
+                 break;
+
+    case MODE_4: len =  (max_visual_linkname_len) ? max_visual_linkname_len + 4 : 0; /* linkname + " -> " */
+		 len += max_visual_filename_len + 39; /* filename + format */
+                 break;
+
+    case MODE_5: len = GetVisualUserFileEntryLength(max_visual_filename_len, max_visual_linkname_len, USERVIEW);
+		 max_visual_userview_len = len;
+		 break;
+  }
+
+  return len;
+}
+
+
+
 
 void RotateFileMode(void)
 {
@@ -697,7 +707,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      sym_link_name
 				    );
 #else
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%8u  %%-12s  %%-12s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%c%%%c%ds  %%8u  %%-12s %%-12s -> %%-%ds",
                                       justify,
 			              filename_width,
 			              linkname_width
@@ -729,7 +739,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      group_name_ptr
 				    );
 #else
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%8u  %%-12s  %%-12s",
+                      (void) sprintf( format, "%%c%%c%%%c%ds  %%8u  %%-12s %%-12s",
                                       justify,
 			              filename_width
 				      );
