@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/hex.c,v 1.13 2001/06/15 16:36:36 werner Exp $
  *
  * View-Hex-Kommando-Bearbeitung
  *
@@ -53,6 +51,9 @@ static int ViewHexFile(char *file_path)
     ESCAPE;
   }
 
+  InternalView(file_path);
+  return(0);
+  
   if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
   {
     ERROR_MSG( "Malloc failed*ABORT" );
@@ -107,7 +108,7 @@ static int ViewHexFile(char *file_path)
   }
     
   
-  if((result = SystemCall( command_line )))
+  if((result = SilentSystemCall( command_line )))
   {
     (void) sprintf( message, "can't execute*%s", command_line );
     MESSAGE( message );
@@ -145,7 +146,7 @@ static int ViewHexArchiveFile(char *file_path)
 			  buffer
 			);
 
-  if((result = SystemCall( command_line )))
+  if((result = SilentSystemCall( command_line )))
   {
     (void) sprintf( message, "can't execute*%s", command_line );
     MESSAGE( message );
