@@ -620,11 +620,11 @@ int AixWgetch( WINDOW *w )
 #endif
 
 
-int Getch()
+int WGetch(WINDOW *win)
 {
   int c;
 
-  c = getch();
+  c = wgetch(win);
 
 #ifdef KEY_RESIZE
   if(c == KEY_RESIZE) {
@@ -636,3 +636,9 @@ int Getch()
   return(c);
 }
 
+
+int Getch()
+{
+  return(WGetch(stdscr));
+}
+
