@@ -1,4 +1,13 @@
+/***************************************************************************
+ *
+ * Funktionen zum Key-Handling
+ *
+ ***************************************************************************/
+
+
 #include "ytree.h"
+
+
 #ifdef READLINE_SUPPORT
 #include "tilde.h"
 #include <readline/readline.h>
@@ -12,9 +21,13 @@ static int total_matches  = 0;
 static int cursor_pos     = 0;
 static int disp_begin_pos = 1;
 
+static void PrintMtchEntry(int entry_no, int y, int color, int start_x, int *hide_left, int *hide_right);
+static int DisplayMatches();
 
-void PrintMtchEntry(int entry_no, int y, int color, 
-                   int start_x, int *hide_left, int *hide_right)
+
+
+static void PrintMtchEntry(int entry_no, int y, int color, 
+                           int start_x, int *hide_left, int *hide_right)
 {
   int     n;
   char    buffer[BUFSIZ];
@@ -89,7 +102,7 @@ void PrintMtchEntry(int entry_no, int y, int color,
 
 
 
-int DisplayMatches()
+static int DisplayMatches()
 {
   int i, hilight_no, p_y;
   int hide_left, hide_right;
