@@ -570,7 +570,7 @@ int LoginDisk(char *path)
     (void) strcpy( statistic.tree->name, path );
     statistic.tree->next = statistic.tree->prev = NULL;
 
-    depth = strtod(TREEDEPTH, NULL);
+    depth = strtol(TREEDEPTH, NULL, 0);
     if( ReadTree( statistic.tree, path, depth ) )
     {
       ERROR_MSG( "ReadTree Failed" );
