@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/profile.c,v 1.9 2004/12/30 18:55:32 werner Exp $
  *
  * Profile support
  *
@@ -56,42 +54,43 @@ static Filemenu filemenu;
 
 /* MUSS sortiert sein! */
 static Profile profile[] = { 
-  { "ARCEXPAND",    DEFAULT_ARCEXPAND,    NULL,     NULL },
-  { "ARCLIST",      DEFAULT_ARCLIST,      NULL,     NULL },
-  { "BUNZIP",       DEFAULT_BUNZIP,       NULL,     NULL },
-  { "CAT",          DEFAULT_CAT,          NULL,     NULL },
-  { "DIR1",         DEFAULT_DIR1,         NULL,     NULL },
-  { "DIR2",         DEFAULT_DIR2,         NULL,     NULL },
-  { "EDITOR",       DEFAULT_EDITOR,       "EDITOR", NULL },
-  { "FILE1",        DEFAULT_FILE1,        NULL,     NULL },
-  { "FILE2",        DEFAULT_FILE2,        NULL,     NULL },
-  { "FILEMODE",     DEFAULT_FILEMODE,     NULL,     NULL },
-  { "GNUUNZIP",     DEFAULT_GNUUNZIP,     NULL,     NULL },
-  { "HEXDUMP",      DEFAULT_HEXDUMP,      NULL,     NULL },
-  { "HEXEDITOFFSET",DEFAULT_HEXEDITOFFSET,NULL,     NULL },
-  { "INITIALDIR",   DEFAULT_INITIALDIR,   NULL,     NULL },
-  { "LHAEXPAND",    DEFAULT_LHAEXPAND,    NULL,     NULL },
-  { "LHALIST",      DEFAULT_LHALIST,      NULL,     NULL },
-  { "MANROFF",      DEFAULT_MANROFF,      NULL,     NULL },
-  { "MELT",         DEFAULT_MELT,         NULL,     NULL },
-  { "NOSMALLWINDOW",DEFAULT_NOSMALLWINDOW,NULL,     NULL },
-  { "NUMBERSEP",    DEFAULT_NUMBERSEP,    NULL,     NULL },
-  { "PAGER",        DEFAULT_PAGER,        "PAGER",  NULL },
-  { "RAREXPAND",    DEFAULT_RAREXPAND,    NULL,     NULL },
-  { "RARLIST",      DEFAULT_RARLIST,      NULL,     NULL },
-  { "RPMEXPAND",    DEFAULT_RPMEXPAND,    NULL,     NULL },
-  { "RPMLIST",      DEFAULT_RPMLIST,      NULL,     NULL },
-  { "SEARCHCOMMAND",DEFAULT_SEARCHCOMMAND,NULL,     NULL },
-  { "TAPEDEV",      DEFAULT_TAPEDEV,      "TAPE",   NULL },
-  { "TAREXPAND",    DEFAULT_TAREXPAND,    NULL,     NULL },
-  { "TARLIST",      DEFAULT_TARLIST,      NULL,     NULL },
-  { "TREEDEPTH",    DEFAULT_TREEDEPTH,    NULL,     NULL },
-  { "UNCOMPRESS",   DEFAULT_UNCOMPRESS,   NULL,     NULL },
-  { "USERVIEW",     "",                   NULL,     NULL },
-  { "ZIPEXPAND",    DEFAULT_ZIPEXPAND,    NULL,     NULL },
-  { "ZIPLIST",      DEFAULT_ZIPLIST,      NULL,     NULL },
-  { "ZOOEXPAND",    DEFAULT_ZOOEXPAND,    NULL,     NULL },
-  { "ZOOLIST",      DEFAULT_ZOOLIST,      NULL,     NULL }
+  { "ARCEXPAND",    	DEFAULT_ARCEXPAND,     NULL,     NULL },
+  { "ARCLIST",      	DEFAULT_ARCLIST,       NULL,     NULL },
+  { "BUNZIP",       	DEFAULT_BUNZIP,        NULL,     NULL },
+  { "CAT",          	DEFAULT_CAT,           NULL,     NULL },
+  { "DIR1",         	DEFAULT_DIR1,          NULL,     NULL },
+  { "DIR2",         	DEFAULT_DIR2,          NULL,     NULL },
+  { "EDITOR",       	DEFAULT_EDITOR,        "EDITOR", NULL },
+  { "FILE1",        	DEFAULT_FILE1,         NULL,     NULL },
+  { "FILE2",        	DEFAULT_FILE2,         NULL,     NULL },
+  { "FILEMODE",     	DEFAULT_FILEMODE,      NULL,     NULL },
+  { "GNUUNZIP",     	DEFAULT_GNUUNZIP,      NULL,     NULL },
+  { "HEXDUMP",      	DEFAULT_HEXDUMP,       NULL,     NULL },
+  { "HEXEDITOFFSET",	DEFAULT_HEXEDITOFFSET, NULL,     NULL },
+  { "INITIALDIR",   	DEFAULT_INITIALDIR,    NULL,     NULL },
+  { "LHAEXPAND",    	DEFAULT_LHAEXPAND,     NULL,     NULL },
+  { "LHALIST",      	DEFAULT_LHALIST,       NULL,     NULL },
+  { "LISTJUMPSEARCH",   DEFAULT_LISTJUMPSEARCH,NULL,     NULL },
+  { "MANROFF",      	DEFAULT_MANROFF,       NULL,     NULL },
+  { "MELT",         	DEFAULT_MELT,          NULL,     NULL },
+  { "NOSMALLWINDOW",	DEFAULT_NOSMALLWINDOW, NULL,     NULL },
+  { "NUMBERSEP",    	DEFAULT_NUMBERSEP,     NULL,     NULL },
+  { "PAGER",        	DEFAULT_PAGER,        "PAGER",  NULL },
+  { "RAREXPAND",    	DEFAULT_RAREXPAND,     NULL,     NULL },
+  { "RARLIST",      	DEFAULT_RARLIST,       NULL,     NULL },
+  { "RPMEXPAND",    	DEFAULT_RPMEXPAND,     NULL,     NULL },
+  { "RPMLIST",      	DEFAULT_RPMLIST,       NULL,     NULL },
+  { "SEARCHCOMMAND",	DEFAULT_SEARCHCOMMAND, NULL,     NULL },
+  { "TAPEDEV",      	DEFAULT_TAPEDEV,       "TAPE",   NULL },
+  { "TAREXPAND",    	DEFAULT_TAREXPAND,     NULL,     NULL },
+  { "TARLIST",      	DEFAULT_TARLIST,       NULL,     NULL },
+  { "TREEDEPTH",    	DEFAULT_TREEDEPTH,     NULL,     NULL },
+  { "UNCOMPRESS",   	DEFAULT_UNCOMPRESS,    NULL,     NULL },
+  { "USERVIEW",     	"",                    NULL,     NULL },
+  { "ZIPEXPAND",    	DEFAULT_ZIPEXPAND,     NULL,     NULL },
+  { "ZIPLIST",      	DEFAULT_ZIPLIST,       NULL,     NULL },
+  { "ZOOEXPAND",    	DEFAULT_ZOOEXPAND,     NULL,     NULL },
+  { "ZOOLIST",      	DEFAULT_ZOOLIST,       NULL,     NULL }
 };
 
 #define PROFILE_ENTRIES (sizeof(profile) / sizeof(profile[0]))
@@ -105,7 +104,7 @@ int ReadProfile( char *filename )
 {
   int  l, result = -1;
   char buffer[1024], *n, *old;
-  unsigned char *name, *value, *cptr;
+  char *name, *value, *cptr;
   int section;
   Profile *p, key;
   Viewer *v, *new_v;
